package com.elitesland.item.controller;

import com.elitesland.core.base.ApiCode;
import com.elitesland.core.base.ApiResult;
import com.elitesland.core.base.PagingVO;
import com.elitesland.item.entity.ItmBrandDO;
import com.elitesland.item.service.ItmBrandService;
import com.elitesland.itm.param.ItmBrandCreateParam;
import com.elitesland.itm.param.ItmBrandQueryParam;
import com.elitesland.itm.param.ItmBrandUpdateParam;
import com.elitesland.itm.vo.ItmBrandVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.val;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 功能说明
 * </p>
 *
 * @author roman.zhang
 * @since 2020-08-17 14:34:21
 */
@RestController
@RequestMapping("//itmBrand")
@Api(value = "品牌", tags = {"品牌"})
@RequiredArgsConstructor
public class ItmBrandController {

    private final ItmBrandService itmBrandService;

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/findIdOne/{id}")
    @ApiOperation("通过主键查询单条数据")
    ApiResult<ItmBrandVO> findIdOne(@PathVariable Long id) {
        return itmBrandService.findIdOne(id).map(ApiResult::ok)
                .orElse(ApiResult.fail(ApiCode.NOT_FOUND));
    }

    /**
     * 根据关键字段查询数据
     *
     * @param key 参数
     * @return 数据
     */
    @GetMapping("/findCodeOne/{key}")
    @ApiOperation("根据关键字段查询数据")
    public ApiResult<ItmBrandVO> findCodeOne(@PathVariable String key) {
        return itmBrandService.findCodeOne(key).map(ApiResult::ok)
                .orElse(ApiResult.fail(ApiCode.NOT_FOUND));
    }

    /**
     * 分页查询
     *
     * @param param 分类查询、分页和排序对象
     * @return 多条数据
     */
    @PostMapping("/search")
    @ApiOperation("分页查询")
    public ApiResult<PagingVO<ItmBrandVO>> search(@RequestBody ItmBrandQueryParam param) {
        val ret = itmBrandService.search(param);
        return ApiResult.ok(ret);
    }

    /**
     * 新增数据
     *
     * @param param 新增数据
     * @return 新增数据情况
     */
    @PostMapping("/createOne")
    @ApiOperation("新增数据")
    public ApiResult<Object> createOne(@RequestBody ItmBrandCreateParam param) {
        ItmBrandDO DO = new ItmBrandDO();
        BeanUtils.copyProperties(param, DO);
        return ApiResult.ok(itmBrandService.createOne(DO));
    }

    /**
     * 批量新增数据
     *
     * @param list 对象集合
     */
    @PostMapping("/createBatch")
    @ApiOperation("批量新增数据")
    public ApiResult<Object> createBatch(@RequestBody List<ItmBrandDO> list) {
        val dos = list.stream().map(i -> {
            ItmBrandDO DO = new ItmBrandDO();
            BeanUtils.copyProperties(i, DO);
            return DO;
        }).collect(Collectors.toList());
        return ApiResult.ok(itmBrandService.createBatch(dos));
    }

    /**
     * 修改数据
     *
     * @param param 修改对象
     * @return 修改数据详情
     */
    @PutMapping("/update")
    @ApiOperation("修改数据")
    public ApiResult<Object> update(@RequestBody ItmBrandUpdateParam param) {
        ItmBrandDO DO = new ItmBrandDO();
        BeanUtils.copyProperties(param, DO);
        itmBrandService.update(DO);
        return ApiResult.ok();
    }

    /**
     * 根据主键删除数据
     *
     * @param id 主键
     * @return 删除情况
     */
    @DeleteMapping("/deleteOne/{id}")
    @ApiOperation("根据主键删除数据")
    public ApiResult<Object> deleteOne(@PathVariable Long id) {
        itmBrandService.deleteOne(id);
        return ApiResult.ok();
    }

    /**
     * 批量删除
     *
     * @param ids 删除数据集合
     */
    @DeleteMapping("/deleteBatch")
    @ApiOperation("批量删除")
    public ApiResult<Object> deleteBatch(@RequestBody List<Long> ids) {
        itmBrandService.deleteBatch(ids);
        return ApiResult.ok();
    }

    /**
     * 逻辑删除
     *
     * @param id 更新数据
     */
    @PutMapping("/updateDeleteFlag/{id}")
    @ApiOperation("逻辑删除")
    public ApiResult<Object> updateDeleteFlag(@PathVariable Long id) {
        itmBrandService.updateDeleteFlag(id);
        return ApiResult.ok();
    }
}
