package com.elitesland.item.entity;

import com.elitesland.core.base.BaseModel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Objects;

/**
 * <p>
 * 功能说明：品牌
 * </p >
 *
 * @author Roman.Zhang
 * @date 2020/7/8
 */

@Entity
@Table(name = "itm_brand")
@DynamicUpdate
@DynamicInsert
@org.hibernate.annotations.Table(appliesTo = "itm_brand", comment = "品牌")
@Data
@Accessors(chain = true)
@ApiModel(value = "ITM_BRAND", description = "品牌")
public class ItmBrandDO extends BaseModel implements Serializable
{
    private static final long serialVersionUID = 4735933553085336616L;

    @ApiModelProperty("品牌代码")
    @Column(columnDefinition = "varchar(8)  comment '品牌代码'")
    private String brandCode;

    @ApiModelProperty("品牌名称")
    @Column(columnDefinition = "varchar(64)  comment '品牌名称'")
    private String brandName;

    @ApiModelProperty("名称2")
    @Column(columnDefinition = "varchar(64)  comment '名称2'")
    private String brandName2;

    @ApiModelProperty("简称")
    @Column(columnDefinition = "varchar(64)  comment '简称'")
    private String abbrName;

    @ApiModelProperty("品牌状态")
    @Column(columnDefinition = "varchar(64)  comment '品牌状态'")
    private String brandStatus;

    @ApiModelProperty("类型 [UDC]COM:BRAND_TYPE")
    @Column(columnDefinition = "varchar(16)  comment '类型 [UDC]COM:BRAND_TYPE'")
    private String brandType;

    @ApiModelProperty("类型2")
    @Column(columnDefinition = "varchar(16)  comment '类型2'")
    private String brandType2;

    @ApiModelProperty("类型3")
    @Column(columnDefinition = "varchar(16)  comment '类型3'")
    private String brandType3;

    @ApiModelProperty("产品组 [UDC]ITM:ITEM_GROUP")
    @Column(columnDefinition = "varchar(64)  comment '产品组 [UDC]ITM:ITEM_GROUP'")
    private String itemGroup;

    @ApiModelProperty("品类")
    @Column(columnDefinition = "varchar(64)  comment '品类'")
    private String itemCate;

    @ApiModelProperty("品牌阶段 [UDC]COM:BRAND_PHASE")
    @Column(columnDefinition = "varchar(64)  comment '品牌阶段 [UDC]COM:BRAND_PHASE'")
    private String brandPhase;

    @ApiModelProperty("品牌层级 [UDC]COM:BRAND_LEVEL")
    @Column(columnDefinition = "varchar(64)  comment '品牌层级 [UDC]COM:BRAND_LEVEL'")
    private String brandLevel;

    @ApiModelProperty("上级ID")
    @Column(columnDefinition = "bigint(18)  comment '上级ID'")
    private Long pid;

    @ApiModelProperty("路径")
    @Column(columnDefinition = "varchar(1024)  comment '路径'")
    private String brandPath;

    @ApiModelProperty("代理商")
    @Column(columnDefinition = "varchar(64)  comment '代理商'")
    private String agency;

    @ApiModelProperty("品牌经理")
    @Column(columnDefinition = "int(18)  comment '品牌经理'")
    private Long managerEmpId;

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof ItmBrandDO)) {
            return false;
        }
        if (!super.equals(o)) {
            return false;
        }
        ItmBrandDO entity = (ItmBrandDO) o;
        return getId().equals(entity.getId());
    }

    @Override
    public int hashCode() {
        return Objects.hash(getId());
    }
}
