package com.elitesland.item.service.impl;

import com.elitesland.core.base.ApiCode;
import com.elitesland.core.base.PagingVO;
import com.elitesland.core.exception.BusinessException;
import com.elitesland.item.convert.ItmBrandConvert;
import com.elitesland.item.entity.ItmBrandDO;
import com.elitesland.item.entity.QItmBrandDO;
import com.elitesland.item.repo.ItmBrandRepo;
import com.elitesland.item.repo.ItmBrandRepoProc;
import com.elitesland.item.service.ItmBrandService;
import com.elitesland.itm.param.ItmBrandQueryParam;
import com.elitesland.itm.vo.ItmBrandVO;
import com.elitesland.utils.BeanCopyUtil;
import com.querydsl.core.types.ExpressionUtils;
import com.querydsl.core.types.Predicate;
import com.querydsl.jpa.impl.JPAQuery;
import lombok.RequiredArgsConstructor;
import lombok.val;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 * <p>
 * 功能说明
 * </p>
 *
 * @author roman.zhang
 * @since 2020-08-17 14:34:22
 */
@Service("itmBrandService")
@RequiredArgsConstructor
public class ItmBrandServiceImpl implements ItmBrandService {

    private final ItmBrandRepo itmBrandRepo;

    private final ItmBrandRepoProc itmBrandRepoProc;


    @Override

    public PagingVO<ItmBrandVO> search(ItmBrandQueryParam param) {
        val ret = itmBrandRepo.findAll(itmBrandRepoProc.where(param), param.getPageRequest());
        val vos = ret.getContent().stream().map(ItmBrandConvert.INSTANCE::doToVO).collect(Collectors.toList());
        return PagingVO.<ItmBrandVO>builder()
                .total(ret.getTotalElements())
                .records(vos)
                .build();
    }

    @Override

    public Optional<ItmBrandVO> findCodeOne(String itemCode) {
        JPAQuery<ItmBrandVO> jpaQuery = itmBrandRepoProc.select(null);
        val jpaQDo = QItmBrandDO.itmBrandDO;
        //设置查询条件
        //jpaQuery.where(jpaQDo.itemCode.eq(itemCode));
        ItmBrandVO vo = jpaQuery.fetchOne();
        return Optional.ofNullable(vo);
    }

    @Override

    public Optional<ItmBrandVO> findIdOne(Long id) {
        return itmBrandRepo.findById(id).map(ItmBrandConvert.INSTANCE::doToVO);
    }

    @Override

    public List<ItmBrandVO> findIdBatch(List<Long> idList) {
        return itmBrandRepo.findAllById(idList).stream().map(
                ItmBrandConvert.INSTANCE::doToVO
        ).collect(Collectors.toList());
    }


    @Override
    @Transactional
    public Long createOne(ItmBrandDO itmBrandDO) {

        return itmBrandRepo.save(itmBrandDO).getId();
    }

    @Override
    @Transactional
    public List<Long> createBatch(List<ItmBrandDO> list) {
        return itmBrandRepo.saveAll(list).stream().map(ItmBrandDO::getId).collect(Collectors.toList());
    }

    @Override
    @Transactional
    public void update(ItmBrandDO objDo) {
        Optional<ItmBrandDO> optional = itmBrandRepo.findById(objDo.getId());
        if (optional.isPresent()) {
            BeanCopyUtil.beanCopyWithIngore(objDo, optional.get(), BeanCopyUtil.getNullPropertyNames(objDo));
            itmBrandRepo.save(optional.get());
        } else {
            throw new BusinessException(ApiCode.FAIL, "修改失败，数据不存在" + objDo.getId());
        }
    }

    @Override
    @Transactional
    public void updateDeleteFlag(Long id) {
        val jpaQDo = QItmBrandDO.itmBrandDO;
        Predicate predicate = jpaQDo.isNotNull();
        predicate = ExpressionUtils.and(predicate, jpaQDo.id.eq(id));
        Optional<ItmBrandDO> optionalItem = itmBrandRepo.findOne(predicate);
        if (optionalItem.isPresent()) {
            ItmBrandDO do1 = optionalItem.get();
            itmBrandRepo.save(do1);
        } else {
            throw new BusinessException(ApiCode.FAIL, "修改失败，数据不存在" + id);
        }
    }


    @Override
    @Transactional
    public void deleteOne(Long id) {

        this.itmBrandRepo.deleteById(id);

    }

    @Override
    @Transactional
    public void deleteBatch(List<Long> list) {
        list.forEach(id -> itmBrandRepo.deleteById(id));
    }
}
